fplll: Lattice algorithms, including LLL with floating-point orthogonalization
==============================================================================

Description
-----------

fplll contains implementations of several lattice algorithms. The
implementation relies on floating-point orthogonalization, and LLL is
central to the code, hence the name.

Website: https://github.com/fplll/fplll

License
-------

-  LGPL V2.1+


Upstream Contact
----------------

-  Martin Albrecht <martinralbrecht+fplll@googlemail.com>
-  Mailing List https://groups.google.com/forum/#!forum/fplll-devel
